@@ -1,12 +1,18 @@
 
 import time
+import argparse
+from collections import deque
 from dashing import VSplit, HSplit, HGauge, HChart
 from .utils import *
-import argparse
 
-parser = argparse.ArgumentParser(description='Process some integers.')
+
+parser = argparse.ArgumentParser(description='asitop: Performance monitoring CLI tool for Apple Silicon')
 parser.add_argument('--interval', type=int, default=1,
-                    help='Display interval for asitop and sampling interval for powermetrics')
+                    help='Display interval, and sampling interval for powermetrics')
+parser.add_argument('--color', type=int, default=2,
+                    help='Choose display color (0~8)')
+parser.add_argument('--avg', type=int, default=30,
+                    help='Interval for averaged values')
 args = parser.parse_args()
 
 
@@ -16,28 +22,28 @@ def main():
     ui = VSplit(
         VSplit(
             HSplit(
-                HGauge(title="E-CPU Usage", val=0, color=2),
-                HGauge(title="P-CPU Usage", val=0, color=2),
+                HGauge(title="E-CPU Usage", val=0, color=args.color),
+                HGauge(title="P-CPU Usage", val=0, color=args.color),
             ),
-            HGauge(title="GPU Usage", val=0, color=2),
+            HGauge(title="GPU Usage", val=0, color=args.color),
             title="Usage Gauge",
-            border_color=2,
+            border_color=args.color,
         ),
         VSplit(
-            HGauge(title="RAM Usage", val=0, color=2),
+            HGauge(title="RAM Usage", val=0, color=args.color),
             HSplit(
-                HGauge(title="E-CPU B/W", val=50, color=2),
-                HGauge(title="P-CPU B/W", val=50, color=2),
-                HGauge(title="GPU B/W", val=50, color=2),
+                HGauge(title="E-CPU B/W", val=50, color=args.color),
+                HGauge(title="P-CPU B/W", val=50, color=args.color),
+                HGauge(title="GPU B/W", val=50, color=args.color),
             ),
-            border_color=2,
+            border_color=args.color,
             title="Memory"
         ),
         HSplit(
-            HChart(title="CPU Power", color=2),
-            HChart(title="GPU Power", color=2),
+            HChart(title="CPU Power", color=args.color),
+            HChart(title="GPU Power", color=args.color),
             title="Power Chart",
-            border_color=2,
+            border_color=args.color,
         ),
     )
 
@@ -102,6 +108,14 @@ def main():
 
     usage_gauges.title = cpu_title
 
+    def get_avg(inlist):
+        avg = sum(inlist)/len(inlist)
+        return avg
+
+    avg_package_power_list = deque([], maxlen=int(args.avg/args.interval))
+    avg_cpu_power_list = deque([], maxlen=int(args.avg/args.interval))
+    avg_gpu_power_list = deque([], maxlen=int(args.avg/args.interval))
+
     clear_console()
 
     while True:
@@ -172,63 +186,94 @@ def main():
 
                     ecpu_bw_percent = int(
                         (bandwidth_metrics["ECPU DCS RD"]+bandwidth_metrics["ECPU DCS WR"])/max_cpu_bw*100)
-                    ecpu_read_GB = round(bandwidth_metrics["ECPU DCS RD"], 1)
-                    ecpu_write_GB = round(bandwidth_metrics["ECPU DCS WR"], 1)
-                    ecpu_bw_gauge.title = "E-CPU R:" + \
-                        str(ecpu_read_GB)+" W:"+str(ecpu_write_GB)
+                    ecpu_read_GB = bandwidth_metrics["ECPU DCS RD"]
+                    ecpu_write_GB = bandwidth_metrics["ECPU DCS WR"]
+                    ecpu_bw_gauge.title = "".join([
+                        "E-CPU R:",
+                        '{0:.1f}'.format(ecpu_read_GB),
+                        "/W:",
+                        '{0:.1f}'.format(ecpu_write_GB),
+                        " GB/s"
+                    ])
                     ecpu_bw_gauge.value = ecpu_bw_percent
 
                     pcpu_bw_percent = int(
                         (bandwidth_metrics["PCPU DCS RD"]+bandwidth_metrics["PCPU DCS WR"])/max_cpu_bw*100)
-                    pcpu_read_GB = round(bandwidth_metrics["PCPU DCS RD"], 1)
-                    pcpu_write_GB = round(bandwidth_metrics["PCPU DCS WR"], 1)
-                    pcpu_bw_gauge.title = "P-CPU R:" + \
-                        str(pcpu_read_GB)+" W:"+str(pcpu_write_GB)
+                    pcpu_read_GB = bandwidth_metrics["PCPU DCS RD"]
+                    pcpu_write_GB = bandwidth_metrics["PCPU DCS WR"]
+                    pcpu_bw_gauge.title = "".join([
+                        "P-CPU R:",
+                        '{0:.1f}'.format(pcpu_read_GB),
+                        "/W:",
+                        '{0:.1f}'.format(pcpu_write_GB),
+                        " GB/s"
+                    ])
                     pcpu_bw_gauge.value = pcpu_bw_percent
 
                     gpu_bw_percent = int(
                         (bandwidth_metrics["GFX DCS RD"]+bandwidth_metrics["GFX DCS WR"])/max_gpu_bw*100)
-                    gpu_read_GB = round(bandwidth_metrics["GFX DCS RD"], 1)
-                    gpu_write_GB = round(bandwidth_metrics["GFX DCS WR"], 1)
-                    gpu_bw_gauge.title = "GPU R:" + \
-                        str(gpu_read_GB)+" W:"+str(gpu_write_GB)
+                    gpu_read_GB = bandwidth_metrics["GFX DCS RD"]
+                    gpu_write_GB = bandwidth_metrics["GFX DCS WR"]
+                    gpu_bw_gauge.title = "".join([
+                        "GPU R:",
+                        '{0:.1f}'.format(gpu_read_GB),
+                        "/W:",
+                        '{0:.1f}'.format(gpu_write_GB),
+                        " GB/s"
+                    ])
                     gpu_bw_gauge.value = gpu_bw_percent
 
-                    total_bw_GB = round(
-                        ecpu_read_GB+ecpu_write_GB+pcpu_read_GB+pcpu_write_GB+gpu_read_GB+gpu_write_GB, 1)
-                    bw_gauges.title = "Memory Bandwidth (GB/s) - total: " + \
-                        str(total_bw_GB)+" GB/s"
+                    total_bw_GB = ecpu_read_GB+ecpu_write_GB+pcpu_read_GB+pcpu_write_GB+gpu_read_GB+gpu_write_GB
+                    bw_gauges.title = "".join([
+                        "Memory Bandwidth (GB/s) - total: ",
+                        '{0:.2f}'.format(total_bw_GB),
+                        " GB/s"
+                    ])
 
                     package_power_W = cpu_metrics_dict["package_W"]
                     if package_power_W > package_peak_power:
                         package_peak_power = package_power_W
-                    power_charts.title = " ".join([
+                    avg_package_power_list.append(package_power_W)
+                    avg_package_power = get_avg(avg_package_power_list)
+                    power_charts.title = "".join([
                         "Package Power: ",
                         '{0:.2f}'.format(package_power_W),
+                        "W - avg: ",
+                        '{0:.2f}'.format(avg_package_power),
                         "W - throttle: ",
                         thermal_throttle,
                     ])
+
                     cpu_power_percent = int(
                         cpu_metrics_dict["cpu_W"]/cpu_max_power*100)
                     cpu_power_W = cpu_metrics_dict["cpu_W"]
                     if cpu_power_W > cpu_peak_power:
                         cpu_peak_power = cpu_power_W
-                    cpu_power_chart.title = " ".join([
+                    avg_cpu_power_list.append(cpu_power_W)
+                    avg_cpu_power = get_avg(avg_cpu_power_list)
+                    cpu_power_chart.title = "".join([
                         "CPU Power: ",
                         '{0:.2f}'.format(cpu_power_W),
+                        "W - avg: ",
+                        '{0:.2f}'.format(avg_cpu_power),
                         "W - peak: ",
                         '{0:.2f}'.format(cpu_peak_power),
                         "W"
                     ])
                     cpu_power_chart.append(cpu_power_percent)
+
                     gpu_power_percent = int(
                         cpu_metrics_dict["gpu_W"]/gpu_max_power*100)
                     gpu_power_W = cpu_metrics_dict["gpu_W"]
                     if gpu_power_W > gpu_peak_power:
                         gpu_peak_power = gpu_power_W
-                    gpu_power_chart.title = " ".join([
+                    avg_gpu_power_list.append(gpu_power_W)
+                    avg_gpu_power = get_avg(avg_gpu_power_list)
+                    gpu_power_chart.title = "".join([
                         "GPU Power: ",
                         '{0:.2f}'.format(gpu_power_W),
+                        "W - avg: ",
+                        '{0:.2f}'.format(avg_gpu_power),
                         "W - peak: ",
                         '{0:.2f}'.format(gpu_peak_power),
                         "W"
